@@ -1,6 +1,6 @@
 package Dist::Zilla::App::Command::perltidy;
 {
-    $Dist::Zilla::App::Command::perltidy::VERSION = '0.13';
+    $Dist::Zilla::App::Command::perltidy::VERSION = '0.14';
 }
 
 use strict;
@@ -8,6 +8,8 @@ use warnings;
 
 # ABSTRACT: perltidy your dist
 use Dist::Zilla::App -command;
+use Path::Iterator::Rule;
+use File::Copy;
 
 sub abstract {'perltidy your dist'}
 
@@ -67,11 +69,37 @@ sub execute {
 
     my $tidy = $backends->{ $opt->{backend} }->();
 
-    require File::Copy;
-    require File::Next;
+# RT 91288
+# copied from https://metacpan.org/source/KENTNL/Dist-Zilla-PluginBundle-Author-KENTNL-2.007000/utils/strip_eol.pl
+    my $rule = Path::Iterator::Rule->new();
+    $rule->skip_vcs;
+    $rule->skip(
+        sub {
+            return if not -d $_;
+            if ( $_[1] =~ qr/^\.build$/ ) {
+                $self->zilla->log_debug('Ignoring .build');
+                return 1;
+            }
+            if ( $_[1] =~ qr/^[A-Za-z].*-[0-9.]+(-TRIAL)?$/ ) {
+                $self->zilla->log_debug('Ignoring dzil build tree');
+                return 1;
+            }
+            return;
+        }
+    );
+    $rule->file->nonempty;
+    $rule->file->not_binary;
 
-    my $files = File::Next::files('.');
-    while ( defined( my $file = $files->() ) ) {
+    # $rule->file->line_match(qr/\s\n/);
+
+    my $next = $rule->iter(
+        '.' => {
+            follow_symlinks => 0,
+            sorted          => 0,
+        }
+    );
+
+    while ( my $file = $next->() ) {
         next unless ( $file =~ /\.(t|p[ml])$/ );    # perl file
         my $tidyfile = $file . '.tdy';
         $self->zilla->log_debug( [ 'Tidying %s', $file ] );
@@ -100,13 +128,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::perltidy - perltidy your dist
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head2 SYNOPSIS
 
@@ -151,7 +181,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Fayland Lam.
+This software is copyright (c) 2014 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
